<?php

namespace DynamicContentForElementor\PluginUtils;

class Manager
{
    /**
     * @var Manager|null
     */
    protected static $instance = null;
    /**
     * @var array<string,mixed>
     */
    protected $config = [];
    /**
     * @var Rollback
     */
    public $rollback;
    /**
     * @var License
     */
    public $license;
    /**
     * @var Cron
     */
    public $cron;
    /**
     * @var WpCli
     */
    public $wpcli;
    /**
     * @var UpdateChecker
     */
    public $update_checker;
    /**
     * @var AdminPages\Manager
     */
    public $admin_pages;
    /**
     * @var Api
     */
    public $api;
    /**
     * @var Assets\Manager
     */
    public $assets;
    /**
     * @param array<string,mixed> $config
     */
    public function __construct($config)
    {
        $this->set_config($config);
        $this->admin_pages = new \DynamicContentForElementor\PluginUtils\AdminPages\Manager($this);
        $this->api = new \DynamicContentForElementor\PluginUtils\Api($this);
        $this->rollback = new \DynamicContentForElementor\PluginUtils\Rollback($this);
        $this->cron = new \DynamicContentForElementor\PluginUtils\Cron($this);
        if (\defined('WP_CLI') && WP_CLI) {
            new \DynamicContentForElementor\PluginUtils\WpCli($this);
        }
        $this->license = new \DynamicContentForElementor\PluginUtils\License($this);
        $this->update_checker = new \DynamicContentForElementor\PluginUtils\UpdateChecker($this);
        $this->assets = new \DynamicContentForElementor\PluginUtils\Assets\Manager($this);
        new \DynamicContentForElementor\PluginUtils\PluginPage($this);
    }
    /**
     * @param array<string,mixed> $config
     * @return self
     */
    public function set_config($config)
    {
        $required_keys = ['plugin_base', 'plugin_slug', 'version', 'plugin_file', 'plugin_name_underscored', 'license_url', 'prefix', 'product_unique_id', 'product_name_long', 'pricing_url'];
        foreach ($required_keys as $key) {
            if (!isset($config[$key])) {
                throw new \Exception("Missing required config key: {$key}");
            }
        }
        $this->config = $config;
        return $this;
    }
    /**
     * @param string $key
     * @return string
     */
    public function get_config($key = '')
    {
        return $this->config[$key] ?? '';
    }
    /**
     * @return array<string,array<string,string>>
     */
    public function get_action_links()
    {
        return $this->config['action_links'] ?? [];
    }
    /**
     * Enqueue admin styles
     * @return void
     */
    public function enqueue_admin_styles()
    {
        wp_enqueue_style($this->get_config('prefix') . '-admin-style', $this->assets->get_assets_url('css/admin-style.css'), [], $this->get_config('version'));
    }
}
